function hos_con

% HOS_CON Show the help for the functions in this toolbox.

% This file is automatically generated.  Matthew Simoneau, 09-04-98
% Copyright (c) 1984-98 by The MathWorks, Inc. All Rights Reserved
% $Revision: 1.12 $ $Date: 1998/12/31 21:14:28 $

helpwin('hos_con/Contents');

function Contents
%MATLAB Tour Partial Function Help:  hos_con
%
%Double click on any function for more information
%
%  Higher-Order Spectral Analysis Toolbox.
%  Version 2.0.3 (R11) 10-Jul-1998
% 
%  New Features.
%    Readme      - Important release information about the HOSA Toolbox 
%                  (double click on Readme, or type "whatsnew directoryname", 
%                   i.e. "whatsnew hosa" to display this file).
% 
%  Higher-Order Spectrum Estimation: conventional methods 
%    cum2x      - Estimates cross-covariance
%    cum3x      - Estimates third-order cross-cumulants
%    cum4x      - Estimates fourth-order cross-cumulants 
%    cumest     - Estimates auto-cumulants, orders two, three, or four 
%                 (cum2est, cum3est, cum4est are sub-ordinate routines) 
%    bicoher    - Estimates bicoherence, direct method 
%    bicoherx   - Estimates cross-bicoherence, direct method 
%    bispecd    - Bispectrum estimation (direct method) 
%    bispecdx   - Cross-Bispectrum estimation (direct method) 
%    bispeci    - Bispectrum estimation (indirect method) 
%    glstat     - Gaussianity-Linearity detection statistics (Hinich test) 
% 
%  Higher-Order Spectrum Estimation: parametric methods
%    armaqs     - Estimates ARMA parameters via q-slice algorithm 
%    armarts    - Estimates ARMA parameters via residual time-series algorithm 
%    armasyn    - Generates ARMA synthetics 
%    arorder    - Estimates AR order 
%    arrcest    - Estimates AR parameters using correlation &/or cumulants 
%    bispect    - Theoretical bispectrum of an ARMA process 
%    cumtrue    - Computes theoretical (true) cumulants of ARMA processes 
%    maest      - Estimates MA parameters (GM algorithm) 
%    maorder    - Estimates MA order 
%    rpiid      - Generates a sequence of i.i.d. random variables, various p.d.f.'s
%    trispect   - Computes 2-D slice of true trispectrum of ARMA process 
% 
%  Quadratic Phase Coupling (QPC) 
%    qpcgen     - Generates quadratically-phase coupled harmonics in noise 
%    qpctor     - Detection of quadratic phase coupling via the TOR method 
%    
%  Second-Order Volterra Systems
%    nlgen      - Computes the output of a second-order Volterra system 
%    nlpow      - Power's method for parameters of 2nd-order Volterra system
%    nltick     - Tick 's method for parameters of 2nd-order Volterra system
% 
%  Harmonic Retrieval 
%    harmest    - Estimates frequencies of harmonics  
%    harmgen    - Generates harmonics in Gaussian (colored) noise 
% 
%  Time-Delay Estimation (TDE) 
%    tde        - Time-delay estimation using third-order cross cumulants 
%    tdeb       - Time-delay estimation using third-order cross bispectrum
%    tdegen     - Generates synthetics for time-delay estimation 
%    tder       - Time-delay estimation using cross-correlation 
%  
%  Array Processing - Direction of Arrival (DOA) estimation 
%    doa        - Estimates number of sources and their bearings (cum2 or cum4) 
%    doagen     - Synthetic generator for the DOA problem 
% 
%  Adaptive Linear Prediction 
%    ivcal      - Computes instrumental variables  (used by rivtr and rivdl)
%    rivdl      - Recursive instrumental variable algorithm: double-lattice filter
%    rivtr      - Recursive instrumental variable algorithm: transversal filter 
% 
%  Impulse Response (IR), Magnitude and Phase Retrieval
%    biceps     - Estimates impulse response via the bicepstrum method 
%    bicepsf    - Estimates impulse response via the bicepstrum (FFT) method 
%    matul      - Magnitude and phase retrieval (Matsuoka-Ulrych algorithm) 
% 
%  Time-Frequency Distributions
%    wig2       - Wigner spectrum
%    wig2c      - Wigner spectrum, with Choi-Williams type filtering
%    wig3       - Wigner bispectrum, diagonal slice 
%    wig3c      - Wigner bispectrum, with Choi-Williams type filtering
%    wig4       - Wigner trispectrum, diagonal slice
%    wig4c      - Wigner trispectrum, with Choi-Williams type filtering
% 
%  Utilities 
%    hprony     - Prony's method for modeling transients 
%    pickpeak   - Picks peaks subject to a separation condition 
%    tls        - Total Least Squares Solution to a set of linear equations 
%    trench     - Trench recursion for non-symmetric Toeplitz matrices
% 
%  Demos and Quick Help
%    hosahelp   - One-line synopsis of all HOSA mfiles 
%    hosademo   - A demo of the HOSA Toolbox
% 
%-------------------------------------------
%
%  Higher-Order Spectral Analysis Toolbox - Demo suite
% 
%  hosademo : main demo file
% 	     all other .m files in this directory are invoked by hosademo
% 
%  Data files: 
% 
%  ar1.mat      - AR(2) synthetic
%  arma1.mat    - ARMA(2,1) synthetic
%  doa1.mat     - synthetic for DOA problem
%  gldat.mat    - data for Gaussianity/linearity tests
%  harm.mat     - synthetic for harmonics in noise problem
%  laff.dat     - a segment of laughter data
%  laff_b.mat   - pre-computed bispectrum of data in laff.dat 
%  lynx.dat     - the lynx data series
%  ma1.mat      - MA(3) synthetic
%  nl1.mat      - synthetic for testing non-linear routines
%  nl2.mat      - synthetic for testing non-linear routines
%  qpc.mat      - signal  for the quadratic phase coupling problem
%  riv.mat      - signals for the adaptive LP problem
%  tde1.mat     - signals for the time-delay estimation problem
%  tprony.mat   - signal  for testing Prony's method
%  wigdat.mat   - signals for testing the Wigner routines
%

function Readme
%MATLAB Tour Partial Function Help:  hos_con
%
%  README file for the HOSA Toolbox.
%  Version 2.0.3 (R11) 10-Jul-1998
% 
%  Note: There have been no changes in Toolbox functionality.
%  *********************************************************************
%  Bug fixes for version 2.0.3:
%   
%  1) CUM4X -  Corrected conjugation errors related to the computation of 
%              R_wy, R_zy and M_yx.  
% 
%  2) TDE -    Corrected a size error when the 'svdflag' input argument was
%              used.
% 
%  *********************************************************************
%  The HOSA Manual:
% 
%  The classification example in the Case Studies section of the Higher 
%  Order Spectral Analysis Toolbox manual does not define x and y. 
%  Users cannot run the example because they do not have the two 
%  underwater acoustic signals.  

function cum2x
%MATLAB Tour Partial Function Help:  hos_con
%
% CUM2X Cross-covariance
% 	y_cum  = cum2x (x,y,maxlag, samp_seg, overlap, flag)
% 	  x,y    - data vectors/matrices with identical dimensions
% 	           if x,y are matrices, rather than vectors, columns are
% 	           assumed to correspond to independent realizations,
% 	           overlap is set to 0, and samp_seg to the row dimension.
% 	  maxlag - maximum lag to be computed    [default = 0]
% 	samp_seg - samples per segment  [default = data_length]
% 	 overlap - percentage overlap of segments [default = 0]
% 	           overlap is clipped to the allowed range of [0,99].
% 	   flag  - 'biased', biased estimates are computed  [default]
% 	          'unbiased', unbiased estimates are computed.
% 	   y_cum - estimated cross-covariance
% 	           E x^*(n)y(n+m),   -maxlag <= m <= maxlag

function cum3x
%MATLAB Tour Partial Function Help:  hos_con
%
% CUM3X Third-order cross-cumulants.
% 	y_cum  = cum3x (x,y,z,maxlag, samp_seg, overlap, flag, k1)
% 	  x,y,z  - data vectors/matrices with identical dimensions
% 	           if x,y,z are matrices, rather than vectors, columns are
% 	           assumed to correspond to independent realizations,
% 	           overlap is set to 0, and samp_seg to the row dimension.
% 	  maxlag - maximum lag to be computed    [default = 0]
% 	samp_seg - samples per segment  [default = data_length]
% 	 overlap - percentage overlap of segments [default = 0]
% 	           overlap is clipped to the allowed range of [0,99].
% 	   flag : 'biased', biased estimates are computed  [default]
% 	          'unbiased', unbiased estimates are computed.
% 	      k1: the fixed lag in c3(m,k1): defaults to 0
% 	   y_cum:  estimated third-order cross cumulant,
% 	           E x^*(n)y(n+m)z(n+k1),   -maxlag <= m <= maxlag

function cum4x
%MATLAB Tour Partial Function Help:  hos_con
%
% CUM4X 	Fourth-order cross-cumulants.
%        y_cum = cum4x (w,x,y,z, maxlag, samp_seg, overlap, flag, k1, k2)
% 	 w,x,y,z  - data vectors/matrices with identical dimensions
% 	           if w,x,y,z are matrices, rather than vectors, columns are
% 	           assumed to correspond to independent realizations,
% 	           overlap is set to 0, and samp_seg to the row dimension.
% 	  maxlag - maximum lag to be computed    [default = 0]
% 	samp_seg - samples per segment  [default = data_length]
% 	 overlap - percentage overlap of segments [default = 0]
% 	           overlap is clipped to the allowed range of [0,99].
% 	   flag : 'biased', biased estimates are computed  [default]
% 	          'unbiased', unbiased estimates are computed.
% 	  k1,k2 : the fixed lags in C4(m,k1,k2); defaults to 0
% 	   y_cum:  estimated fourth-order cross cumulant,
%           c4(t1,t2,t3) := cum( w^*(t), x(t+t1), y(t+t2), z^*(t+t3) )

function cumest
%MATLAB Tour Partial Function Help:  hos_con
%
% CUMEST	Second-, third- or fourth-order cumulants.
% 	y_cum = cumest (y, norder, maxlag, samp_seg, overlap, flag, k1, k2)
% 	       y - time-series  - should be a vector
% 	  norder - cumulant order: 2, 3 or 4 [default = 2]
% 	  maxlag - maximum cumulant lag to compute [default = 0]
% 	samp_seg - samples per segment  [default = data_length]
% 	 overlap - percentage overlap of segments [default = 0]
% 	           overlap is clipped to the allowed range of [0,99].
% 	   flag  - 'biased' or 'unbiased'  [default = 'biased']
% 	  k1,k2  - specify the slice of 3rd or 4th order cumulants
% 	  y_cum  - C2(m) or C3(m,k1) or C4(m,k1,k2),  -maxlag <= m <= maxlag
% 	           depending upon the cumulant order selected

function bicoher
%MATLAB Tour Partial Function Help:  hos_con
%
% BICOHER - Direct (FD) method for estimating bicoherence
% 	[bic,waxis] = bicoher (y,  nfft, wind, segsamp, overlap)
% 	y     - data vector or time-series
% 	nfft - fft length [default = power of two > segsamp]
% 	       actual size used is power of two greater than 'nsamp'
% 	wind - specifies the time-domain window to be applied to each
% 	       data segment; should be of length 'segsamp' (see below);
% 		otherwise, the default Hanning window is used.
% 	segsamp - samples per segment [default: such that we have 8 segments]
% 	        - if x is a matrix, segsamp is set to the number of rows
% 	overlap - percentage overlap, allowed range [0,99]. [default = 50];
% 	        - if x is a matrix, overlap is set to 0.
% 	bic     - estimated bicoherence: an nfft x nfft array, with origin
% 	          at the center, and axes pointing down and to the right.
% 	waxis   - vector of frequencies associated with the rows and columns
% 	          of bic;  sampling frequency is assumed to be 1.

function bicoherx
%MATLAB Tour Partial Function Help:  hos_con
%
% BICOHERX - Direct (FD) method for estimating cross-bicoherence
% 	[bic,waxis] = bicoherx (w,x,y,  nfft, wind, segsamp, overlap)
% 	w,x,y - data vector or time-series
% 	      - should have identical dimensions
% 	nfft - fft length [default = power of two > nsamp]
% 	       actual size used is power of two greater than 'nsamp'
% 	wind - specifies the time-domain window to be applied to each
% 	       data segment; should be of length 'segsamp' (see below);
% 		otherwise, the default Hanning window is used.
% 	segsamp - samples per segment [default: such that we have 8 segments]
% 	        - if x is a matrix, segsamp is set to the number of rows
% 	overlap - percentage overlap, 0 to 99  [default = 50]
% 	        - if y is a matrix, overlap is set to 0.
% 	bic     - estimated cross-bicoherence: an nfft x nfft array, with
% 	          origin at center, and axes pointing down and to the right.
% 	waxis   - vector of frequencies associated with the rows and columns
% 	          of bic;  sampling frequency is assumed to be 1.

function bispecd
%MATLAB Tour Partial Function Help:  hos_con
%
% BISPECD Bispectrum estimation using the direct (fft-based) approach.
% 	[Bspec,waxis] = bispecd (y,  nfft, wind, segsamp, overlap)
% 	y    - data vector or time-series
% 	nfft - fft length [default = power of two > segsamp]
% 	wind - window specification for frequency-domain smoothing
% 	       if 'wind' is a scalar, it specifies the length of the side
% 	          of the square for the Rao-Gabr optimal window  [default=5]
% 	       if 'wind' is a vector, a 2D window will be calculated via
% 	          w2(i,j) = wind(i) * wind(j) * wind(i+j)
% 	       if 'wind' is a matrix, it specifies the 2-D filter directly
% 	segsamp - samples per segment [default: such that we have 8 segments]
% 	        - if y is a matrix, segsamp is set to the number of rows
% 	overlap - percentage overlap [default = 50]
% 	        - if y is a matrix, overlap is set to 0.
% 
% 	Bspec   - estimated bispectrum: an nfft x nfft array, with origin
% 	          at the center, and axes pointing down and to the right.
% 	waxis   - vector of frequencies associated with the rows and columns
% 	          of Bspec;  sampling frequency is assumed to be 1.

function bispecdx
%MATLAB Tour Partial Function Help:  hos_con
%
% BISPECDX Cross-Bispectrum estimation using the direct (fft-based) approach.
% 	[Bspec,waxis] = bispecdx (x,y,z, nfft, wind, segsamp,overlap,plotflag)
% 	x    - data vector or time-series
% 	y    - data vector or time-series  (same dimensions as x)
% 	z    - data vector or time-series  (same dimensions as x)
% 	nfft - fft length [default = power of two > segsamp]
% 	wind - window specification for frequency-domain smoothing
% 	       if 'wind' is a scalar, it specifies the length of the side
% 	          of the square for the Rao-Gabr optimal window  [default=5]
% 	       if 'wind' is a vector, a 2D window will be calculated via
% 	          w2(i,j) = wind(i) * wind(j) * wind(i+j)
% 	       if 'wind' is a matrix, it specifies the 2-D filter directly
% 	segsamp - samples per segment [default: such that we have 8 segments]
% 	        - if x is a matrix, segsamp is set to the number of rows
% 	overlap - percentage overlap, allowed range [0,99]. [default = 50];
% 	        - if x is a matrix, overlap is set to 0.
% 	plotflag- if 0, cross-bispectrum will not be displayed [default=1]
% 	Bspec   - estimated bispectrum: an nfft x nfft array, with origin
% 	          at the center, and axes pointing down and to the right.
% 	waxis   - vector of frequencies associated with the rows and columns
% 	          of Bspec;  sampling frequency is assumed to be 1.

function bispeci
%MATLAB Tour Partial Function Help:  hos_con
%
% BISPECI Bispectrum estimation using the indirect method. 
% 	[Bspec,waxis] = bispeci (y,nlag,segsamp,overlap,flag,nfft, wind)
% 	y       - data vector or time-series   
% 	nlag    - number of lags to compute [must be specified] 
% 	segsamp - samples per segment    [default: row dimension of y]
% 	overlap - percentage overlap     [default = 0] 
% 	flag    - 'biased' or 'unbiased' [default is 'unbiased']
% 	nfft    - FFT length to use      [default = 128] 
% 	wind    - window function to apply: 
% 	      if wind=0, the Parzen window is applied (default); 
% 	      otherwise the hexagonal window with unity values is applied. 
% 	Bspec   - estimated bispectrum  it is an nfft x nfft array
% 	    with origin at the center, and axes pointing down and to the right
% 	waxis   - frequency-domain axis associated with the bispectrum. 
% 	        - the i-th row (or column) of Bspec corresponds to f1 (or f2)
% 	          value of waxis(i). 

function glstat
%MATLAB Tour Partial Function Help:  hos_con
%
% GLSTAT	Detection statistics for Hinich's Gaussianity and linearity tests
% 	[sg, sl] = glstat(x,cparm,nfft)
% 	x     - time series
% 	cparm - resolution (smoothing) parameter c;
% 	        0.5 < c < 1.0 [default = 0.51]
% 	        increasing c reduces the variance,
% 	        but increases the bias (window bandwidth).
% 	nfft  - fft length [default = 128]
% 	sg    - statistic for the Gaussianity test
% 	        [observed chi_sq value, dg, PFA]
% 	sl    - statistic for the linearity test
% 	        [R_estimated, lambda, R_theoretical]
% 
% 	Under the assumption of Gaussianity, the test statistics S is
% 	      chi-squared distributed with df degrees of freedom.
% 	Under the assumption of non-zero skewness and linearity, the test
% 	      statistic R should be approximately equal to the inter-quartile
% 	      range of a chi-squared distribution with two degrees of freedom,
% 	      and non-centrality parameter lambda.
% 

function armaqs
%MATLAB Tour Partial Function Help:  hos_con
%
% ARMAQS	Estimates ARMA parameters via the q-slice algorithm.
% 	[avec, bvec] = armaqs(y,p,q, norder,maxlag,samp_seg,overlap,flag)
% 	      y : time-series (vector or matrix)
% 	      p : AR order
% 	      q : MA order
% 	  norder: cumulant order:  3 or 4         [default = 3 ]
% 	  maxlag: maximum cumulant lag to be used [default = p + q]
% 	samp_seg: samples per segment for estimating cumulants
% 	                                          [default = length of y]
% 	overlap : percentage overlap of segments  [default = 0]
% 	   flag : 'biased' or 'unbiased'          [default = 'biased']
% 	   avec : estimated AR parameter vector
% 	   bvec : estimated MA parameter vector

function armarts
%MATLAB Tour Partial Function Help:  hos_con
%
% ARMARTS Estimates ARMA parameters via the residual time series method.
% 	[avec, bvec] = armarts(y,p,q, norder,maxlag,samp_seg,overlap,flag)
% 	      y : time-series (vector or matrix)
% 	      p : AR order
% 	      q : MA order
% 	  norder: cumulant order: -4, -3, 3 or 4      [default = 3 ]
% 	          -3 : use correlations and 3rd order cumulants
% 	          -4 : use correlations and 4th order cumulants
% 	  maxlag:  maximum cumulant lag to be used    [default = p+q]
% 	samp_seg: samples per segment for estimating cumulants
% 	                                              [default = length of y]
% 	overlap : percentage overlap of segments      [default = 0]
% 	   flag : 'biased' or 'unbiased'              [default = 'biased']
% 	   avec : estimated AR parameter vector
% 	   bvec : estimated MA parameter vector

function armasyn
%MATLAB Tour Partial Function Help:  hos_con
%
% ARMASYN Generates ARMA synthetics.
% 	zmat = armasyn(default)
% 	if default > 0, default settings are used, otherwise
% 	the user is prompted for all parameters.
% 	zmat is the  generated ARMA synthetics; each column corresponds
%                to a different realization

function arorder
%MATLAB Tour Partial Function Help:  hos_con
%
% ARORDER  estimates AR order
% 	p   = arorder (y, norder, pmax, qmax, flag)
% 	y      - time-series
% 	norder - cumulant order to use, should be 2,3,4,-3 or -4 [default = 3]
% 	         a value of -3 (-4) indicates that both correlation
% 	         and third- (fourth-) order cumulants should be used
% 	pmax   - maximum AR order  [default = 10]
% 	qmax   - maximum MA order  [default = 10]
% 	flag   - if 1, the internally chosen AR order is returned in 'p',
% 	         otherwise, the plot of singular values is displayed,
% 	         and the user is prompted to choose the order.
% 	p      - estimated AR order

function arrcest
%MATLAB Tour Partial Function Help:  hos_con
%
% ARRCEST AR parameter estimates based on cumulants.
% 	avec = arrcest (y,p,q, norder,maxlag,samp_seg,overlap,flag)
% 	    y : time-series (vector or matrix)
% 	    p : AR order
% 	    q : MA order
% 	norder: cumulant order: 2, 3 or 4         [default = 2]
% 	         -3 : use correlations and 3rd order cumulants
% 	         -4 : use correlations and 4th order cumulants
% 	  maxlag:  maximum cumulant lag to be used  [default = p+q]
% 	samp_seg: samples per segment for estimating cumulants
% 	                           [default = length of y]
% 	overlap : percentage overlap of segments    [default = 0]
% 	   flag : 'biased' or 'unbiased'            [default = 'biased']
% 	avec    : estimated AR parameter vector

function bispect
%MATLAB Tour Partial Function Help:  hos_con
%
% BISPECT  Theoretical bispectrum of an ARMA model
% 	[Bspec,waxis] = bispect (ma, ar,  nfft)
% 	ma   - ma parameter vector
% 	ar   - ar parameter vector [default: [1]]
% 	nfft - FFT length          [default: 512]
% 	Bspec - Bispectrum of ARMA model, an nfft by nfft array
% 	        with axes pointing down and right
% 	waxis - frequency axis associated with the rows/columns of Bspec

function cumtrue
%MATLAB Tour Partial Function Help:  hos_con
%
% CUMTRUE Theoretical cumulants of an ARMA model
% 	cmat = cumtrue (ma, ar, norder, nlags, k)
% 	    ma - MA parameter vector
% 	    ar - AR parameter vector;  defaults to [1] (pure MA model)
% 	norder - cumulant order: should be 2, 3 or 4;  defaults to 3
% 	 nlags - maximum number of cumulant lags to compute.
% 	         default value is p+q, where p and q are the AR and MA orders
% 	     k - if norder=4, k specifies the 3rd lag of the cumulant;
% 	         default value is 0.
% 	  cmat - computed cumulant vector or matrix.
% 	If norder=2, cmat is a column vector of length 2*nlags + 1,
% 	     and consists of C2(m), m=-nlags, .... , nlags
% 	If norder=3, cmat is a (2*nlags + 1) by (2*nlags + 1) matrix;
% 	      C3(i,j) is returned in cmat(i+nlags+1,j+nlags+1),
% 	              i,j = -nlags, ... , nlags
% 	      note that the axes point down and right; origin is at center
% 	If norder=4, cmat is a (2*nlags + 1) by (2*nlags + 1) matrix;
% 	      C4(i,j,k) is returned in cmat(i+nlags+1,j+nlags+1),
% 	              i,j = -nlags, ... , nlags
% 	      note that the axes point down and right; origin is at center

function maest
%MATLAB Tour Partial Function Help:  hos_con
%
% MAEST  MA parameter estimation via the GM-RCLS algorithm, with Tugnait's fix
% 	bvec = maest (y, q, norder, samp_seg, overlap, flag)
% 	      y  - time-series (vector or matrix)
% 	      q  - MA order
% 	  norder - cumulant-order to use  [default = 3]
% 	samp_seg - samples per segment for cumulant estimation
% 	           [default: length of y]
% 	 overlap - percentage overlap of segments  [default = 0]
% 	    flag - 'biased' or 'unbiased'          [default = 'biased']
% 	    bvec - estimated MA parameter vector

function maorder
%MATLAB Tour Partial Function Help:  hos_con
%
% MAORDER MA order  determination
% 	qopt = maorder(x, qmin, qmax,pfa, flag)
% 	x    - time series (must be a vector)
% 	qmin - minimum MA order    [default = 0]
% 	qmax - maximum MA order    [default = 10]
% 	pfa  - probability of false alarm  [default = 0.05]
% 	flag - if non-zero (default is 1), various values are displayed
% 	qopt - estimated MA order

function rpiid
%MATLAB Tour Partial Function Help:  hos_con
%
% RPIID	Generates samples of an i.i.d. random process. 
% 	u = rpiid (nsamp, in_type, p_spike)
% 	
% 	Generates nsamp i.i.d. samples of a random variable drawn from
% 	the distribution specified by the string in_type:
% 	  'exp' -- exponential     'lap' -- Laplacian  'nor' Gaussian
% 	  'bga'  -- Bernoulli-Gaussian   'uni'-- uniform
% 	  only the first character of the string is checked 
% 	the default distribution is Gaussian ('nor').
% 	p_spike is the probability of spike for Bernoulli-Gaussian ('bga') 
% 	   its default value is 0.1 
% 	   
% 	The theoretical mean is subtracted from the generated sequence
% 	unless, in_type is 'bga'. 
% 	u is the nsamp x 1 vector of random variables 

function trispect
%MATLAB Tour Partial Function Help:  hos_con
%
% TRISPECT  Theoretical trispectrum of an ARMA model: 2-D slice
% 	[Tspec,waxis] = trispect (ma, ar,  nfft, f3)
% 	ma   - ma parameter vector
% 	ar   - ar parameter vector [default: [1]]
% 	nfft - FFT length          [default: 512]
%        f3   - fixed frequency of third argument; default value is 0.
% 		nominal range is [-0.5,0.5]
% 	Tspec - Trispectrum of ARMA model, an nfft by nfft array
% 	        with axes pointing down and right
% 		Contains the trispectrum S3(f1,f2,f3), where
% 			f3 is fixed.
% 	waxis - frequency axis associated with the rows/columns of Tspec

function qpcgen
%MATLAB Tour Partial Function Help:  hos_con
%
% QPCGEN	Generates synthetics for the quadratic phase-coupling problem.
% 	zdat = qpcgen(default)
% 	If parameter 'default' is passed, the default values are used;
% 	otherwise, the user is prompted for all parameters

function qpctor
%MATLAB Tour Partial Function Help:  hos_con
%
% QPCTOR	 Estimation of quadratic-phase coupling using third-order cumulants.
% 	[arvec,Bspec] = qpctor(y, maxlag,ar_order, nfft, nsamp,overlap,flag)
% 	y        - data vector or matrix
% 	maxlag   - maximum number of cumulant lags to use  [default: 12]
% 	ar_order - AR order                       [default: prompt user]
% 	nfft     - fft length for bispectrum      [default = 64]
% 	nsamp    - number of samples per record   [row dimension of y]
% 	overlap  - percentage overlap              [default = 0]
% 	flag     - 'biased' or 'unbiased'         [default = 'biased']
% 	arvec    - estimated AR parameters
% 	Bspec    - estimated bispectrum, an nfft/2 by nfft upper
% 	         - triangular array, corresponding to the
% 	         - 0 <= f2 <= f1 < 0.5

function nlgen
%MATLAB Tour Partial Function Help:  hos_con
%
% NLGEN	generates the output of a second order Volterra system
% 	y = nlgen (x, h, q)
% 	y(n) = sum_{k} h(k) x(n-k) + sum_{k} sum_{l} q(k,l) x(n-k)x(n-l)
%             the filters are assumed to be causal
% 	 x is the input time series;  if x is a matrix, columns are assumed
% 	   to correspond to different realizations.
% 	h is the linear part of the transfer function; must be real
% 	q is the quadratic part of the transfer function; must be real
%          and symmetric;  the origin is at (1,1) with  axes pointing
%          downwards and to the right
% 	y is the output of the Volterra system (same dimensions as x).
% 

function nlpow
%MATLAB Tour Partial Function Help:  hos_con
%
% NLPOW	Second-order Volterra System Identification, arbitrary input
% 	[h, q] = nlpow (x, y, nfft);
% 	x   - input to the Volterra system
% 	y   - output of the Volterra system
% 	     x,y must have identical dimensions;
% 	     if matrices, columns correspond to realizations.
% 	nfft - FFT length to use
% 	h   - estimated IR of the linear part
% 	q   - estimated IR of the quadratic part
% 	    origin at (1,1), with axes pointing right and downwards

function nltick
%MATLAB Tour Partial Function Help:  hos_con
%
% NLTICK Second-order Volterra System Identification, for Gaussian inputs
% 	[h, q] = nltick(x,y,nfft,wind,segsamp,overlap)
% 	x  - input to the Volterra system
% 	y  - output of the Volterra system
% 	x and y must have identical dimensions;  multiple realizations
% 	     are required, with columns corresponding to realizations.
% 	nfft - FFT length to use for computing power spectra/bispectra
% 	wind - window specification for frequency-domain smoothing
% 	       if 'wind' is a scalar, it specifies the length of the side
% 	          of the square for the Rao-Gabr optimal window  [default=5]
% 	       if 'wind' is a vector, a 2D window will be calculated via
% 	          w2(i,j) = wind(i) * wind(j) * wind(i+j)
% 	       if 'wind' is a matrix, it specifies the 2-D filter directly
% 	segsamp - samples per segment [default: so as to have 8 records]
% 	        - if x is a matrix, segsamp is set to the number of rows
% 	overlap - percentage overlap, allowed range [0,99]. [default = 50];
% 	        - if x is a matrix, overlap is set to 0.
% 	h   - estimated IR of the linear part
% 	q   - estimated IR of the quadratic part

function harmest
%MATLAB Tour Partial Function Help:  hos_con
%
% HARMEST Frequencies of harmonics in colored Gaussian noise.
% 	[Pxx,ar1,ar2] = harmest(y,maxlag,p_order,flag,nfft,norder)
% 	      y - data  matrix [nsamp x nrecs]
% 	 maxlag - number of cumulant lags to compute [default = nsamp/12]
% 	p_order - order to use (dimension of signal subspace)
% 	          user will be prompted if p_order <= 0
% 	   flag - 'biased' or 'unbiased'
% 	   nfft - fft length for spectra [default = 256]
% 	 norder - cumulant order to use: 2 or 4 [default = 4]
% 
% 	   Pxx  - a  nfft x 7 matrix of spectral estimates
% 	   ar1  - estimated parameters for the AR method.
% 	   ar2  - estimated parameters for the min-norm method
% 
% 	The seven columns of Pxx contain the spectral estimates based on
% 	the Eigenvector, Music, Pisarenko, ML, AR, periodogram methods,
% 	and the minimum-norm method.
% 

function harmgen
%MATLAB Tour Partial Function Help:  hos_con
%
% HARMGEN Synthetics for the harmonic retrieval problem
% 	zmat = harmgen(default)
% 	If parameter 'default' is passed, the default values are used;
% 	otherwise, the user is prompted for all parameters

function tde
%MATLAB Tour Partial Function Help:  hos_con
%
% TDE	Time-delay estimation using cross-cumulant method.
% 	[delay,avec] = tde(x,y, max_delay,nsamp,svdflag)
% 	x        - data at sensor 1
% 	y        - data at sensor 2
% 	max_delay - maximum delay
% 	nsamp     - samples/record for computing cumulants
% 	svdflag   - if its value is non-zero, the SVD will be computed and
% 	            you will be asked to choose an order for the low-rank
% 	            approximation;  default value is 0
% 	delay     - estimated delay (positive means that y lags x)
% 	avec      - the "AR vector" in the parametric method

function tdeb
%MATLAB Tour Partial Function Help:  hos_con
%
% TDEB	Time Delay Estimation using conventional bispectrum method.
% 	[delay,ctau] = tdeb (x,y,  max_delay, nfft, wind, segsamp, overlap)
% 	x         - signal at sensor 1
% 	y         - signal at sensor 2
% 	max_delay - maximum expected delay in samples
% 	nfft - fft length [default = power of two >= segsamp]
% 	wind - window specification for frequency-domain smoothing
% 	       if 'wind' is a scalar, it specifies the length of the side
% 	          of the square for the Rao-Gabr optimal window  [default=5]
% 	       if 'wind' is a vector, a 2D window will be calculated via
% 	          w2(i,j) = wind(i) * wind(j) * wind(i+j)
% 	       if 'wind' is a matrix, it specifies the 2-D filter directly
% 	segsamp - samples per segment [default: 4*max_delay+1]
% 	        - if x is a matrix, segsamp is set to the number of rows
% 	overlap - percentage overlap, allowed range [0,99]. [default = 50];
% 	        - if x is a matrix, overlap is set to 0.
% 	delay     - estimated delay (in samples)
%        ctau      - estimated third-order hologram.

function tdegen
%MATLAB Tour Partial Function Help:  hos_con
%
% TDEGEN	Synthetics for time-delay estimation
% 	[s1, s2] = tdegen(default)
% 	 s1, s2  noisy signals at the two sensors
% 	If the parameter 'default' is passed, the default settings are
% 	used; otherwise, the user is prompted for all parameters.

function tder
%MATLAB Tour Partial Function Help:  hos_con
%
% TDER	Time-Delay Estimation using ML windowed cross-correlation
% 	[delay,rxy] = tder(s1,s2,max_delay,segsamp,overlap,nfft)
% 	s1       - data at sensor 1
% 	s2       - data at sensor 2
% 	           s1 and s2 should have the same dimensions
% 	max_delay  - maximum delay
% 	segsamp - if not specified, set equal to the power of 2 just
% 	          greater than 4*max_delay + 1;
% 	        - if s1 is a matrix, segsamp is set to the number of rows
% 	overlap - percentage overlap, allowed range [0,99]. [default = 50];
% 	        - if s1 is a matrix, overlap is set to 0.
% 	nfft - FFT length [default = power of two > segsamp]
% 	delay      - estimated delay (positive means that y lags x)
% 	rxy        - estimate of windowed cross-correlation function.

function doa
%MATLAB Tour Partial Function Help:  hos_con
%
% DOA	Direction-of-arrival estimation. 
% 	[spec,theta] = doa(ymat, dspace, dtheta,nsource,order,delta)
% 	 ymat  - sensor array data: each column corresponds to a different 
% 	         sensor; rows correspond to time samples (snapshots)
% 	dspace - array spacing "d" in units of wavelengths    default = 0.5
% 	dtheta - angular resolution in degrees                default = 2. 
%        nsource - number of sources: default value is 0; the singular values
%                 of the cross-cumulant or cross-correlation matrix 
% 		 (see `order' below) will be displayed, and the user will
% 	         be prompted to enter the number of sources. 
% 	order   - cumulant order to use; should be 2 or 4;    default = 4
% 	delta  - displacement (in number of elements) for ESPRIT [default = 1]
% 	  spec - is the array of estimated ``spectra'';  the columns
% 	         correspond to estimates based on the Eigenvector, Music, 
% 	           Pisarenko, ML, AR, min-norm and beamformer methods. 
% 	 theta -  Vector of  bearings corresponding to the rows of spec
% 	bearing - Vector of source bearings (in degrees) estimated by ESPRIT. 

function doagen
%MATLAB Tour Partial Function Help:  hos_con
%
% DOAGEN	Synthetics for the DOA problem.
% 	smat = doagen(default)
% 	If parameter 'default' is passed, the default settings are used;
% 	otherwise, the user is prompted for all parameters.
% 
% 	smat is the nsamp x msens matrix of noisy sensor signals
% 	     nsamp is the number of samples,
% 	     msens is the number of sensors.
% 

function ivcal
%MATLAB Tour Partial Function Help:  hos_con
%
% IVCAL	Instrumental variables
% 	z = ivcal (y, morder, lam)
% 	 y     - input time series (vector or matrix)
% 	morder - cumulant order;  default = 3;
% 	lam    - forgetting factor: range (0,1]; default = 1;
% 
% 	 z     - instrumental variable, computed as follows:
% 	 morder       z(n)
% 	 q <= 0      y(n+q)       (delay)
% 	   1         sign (y(n)
% 	   2         y(n)
% 	   3         y^2(n)
% 	   4         y^3(n) - 3 s(n) * y(n)
% 	where s(n) is the estimated variance, at sample n.

function rivdl
%MATLAB Tour Partial Function Help:  hos_con
%
% RIVDL	Recursive instrumental variable algorithm using the double lattice
% 	[arvec, fref, bref, fpe] = rivdl(y,morder,p,lam,delta,thres,nsmuth)
% 	      y - data vector
% 	 morder - cumulant order (2, 3 or 4;  default = 4)
% 	      p - number of stages                          (default = 2)
% 	    lam - forgetting factor:  0 < lambda =< 1;      (default = 0.998 )
% 	  delta - initialization value for F(n=0) and B(n=0) (default = 0.01)
% 	  thres - threshold check for division by "zero"    (default = 0.0001)
% 	 nsmuth - smoothing window for AR estimation
% 	          the default value is  min(nsamp/4,50),
% 	          where nsamp is the length of the time-series y.
% 	 arvec - AR parameters corresponding to the smoothed final reflection
% 	         coefficient estimates
% 	fref, bref -  forward and backward reflection coefficients of the top
% 	              lattice; rows correspond to time;
% 	              columns s correspond to stages.
% 	 fpe   - final prediction error (upper leg of lattice)

function rivtr
%MATLAB Tour Partial Function Help:  hos_con
%
% RIVTR	 Recursive instrumental algorithm using the transversal structure.
% 	[arvec, fpe, wt] = rivtr(y,morder,arorder,lambda,delta,nsmuth)
% 	      y - time series
% 	 morder - cumulant order          [default = 4]
% 	arorder - AR order                [default = 2]
% 	 lambda - forgetting factor       [default = 0.998]
% 	 delta  - initialization constant [sign(R_zy(0))]
% 	          where z = ivcal(y,morder,1), & R_zy(0) = E ( y(n) z(n) )
% 	 nsmuth - smoothing window for AR estimation
% 	          The default value is  min(nsamp/4,50), where
% 	          nsamp is the length of the time-series y.
% 	  arvec - steady-state AR parameter vector
% 	   fpe  - prediction error
% 	    wt  - weight matrix (as a function of time)
% 	          each row corresponds to a time sample

function biceps
%MATLAB Tour Partial Function Help:  hos_con
%
% BICEPS	Non-parametric system identification using the bicepstrum. 
% 	BICEPS estimates the complex cepstrum, using third-order
% 	cumulants, and then reconstructs the impulse response. 
% 
% 	[hest,ceps,A,B,minh,maxh] = biceps(y,p,q,sampseg,overlap,flag,lh)  
% 	      y - data vector or matrix
% 	    p,q - cepstral orders (truncation points)   [MUST be specified]
% 	sampseg - samples per record                    [default = row size] 
% 	overlap - percentage overlap of records         [default = 0; max=99] 
% 	  flag  - 'biased' or 'unbiased'                [default = 'biased'] 
% 	    lh  - hest indices will range from -lh to lh [default = 2(p+q)]
%  
% 	if y is a matrix, each column is assumed to be a different realization
% 	or record; in this case, overlap is set to 0, and record size is set 
% 	to the row length of the matrix. 
%  
% 	hest - estimated impulse response, h(n):  n= -lh, ... ,lh  
% 	ceps - estimated complex cepstrum 
% 	A    - estimated A(k)'s, k=1,...,p
% 	B    - estimated B(k)'s, k=1,...,q 
%        minh - minimum phase component of hest; length lh+1
% 	maxh - maximum phase component of hest; length lh+1 

function bicepsf
%MATLAB Tour Partial Function Help:  hos_con
%
% BICEPSF Non-parametric IR estimation using the bicesptrum (FFT method)
% 	[hest, ceps] = bicepsf (y,nlag,segsamp,overlap,flag,nfft, wind)
% 	y       - data vector or time-series
% 	nlag    - number of lags to compute [must be specified]
% 	segsamp - samples per segment    [default: row dimension of y]
% 	overlap - percentage overlap     [default = 0]
% 	flag    - 'biased' or 'unbiased' [default is 'unbiased']
% 	nfft    - FFT length to use      [default = 128]
% 	wind    - window function to apply:
% 	      if wind=0, the Parzen window is applied (default);
% 	      otherwise the hexagonal window with unity values is applied.
%        hest    - estimated impulse response
%        ceps    - estimated complex cepstrum

function matul
%MATLAB Tour Partial Function Help:  hos_con
%
% MATUL	Impulse response estimation using Matsuoka-Ulrych algorithm
% 	hest = matul(bisp)
% 	bisp  - the estimated bispectrum
% 	        (e.g., as computed by bispecd or bispeci).
% 	 hest - estimated impulse response

function wig2
%MATLAB Tour Partial Function Help:  hos_con
%
% WIG2	 Computes the Wigner Distribution (second-order)
% 	[wx,waxis] = wig2 (x, nfft,flag)
% 	x     - time series, must be a vector
% 	nfft  - FFT length to use; default is the power of 2 just larger
% 	        than twice the length of x.
% 	flag  - By default, if signal 'x' is real valued, its analytic form
% 	        is used to compute the WD; this helps supress cross terms
% 	        around D.C.;  if flag is 0, the analytic form is not used.
% 	wx    - the Wigner distribution
% 	        rows correspond to time, columns to frequencies
% 	        time increases with row number, frequencies with col number
% 	waxis - the frequency axis associated with the WD
%        It is recommended that the analytic form of the signal be used.

function wig2c
%MATLAB Tour Partial Function Help:  hos_con
%
% WIG2C	 Computes the Wigner Distribution with Choi-Williams filtering
% 	[wx,waxis] = wig2c (x, nfft, sigma,flag)
% 	x     - time series, must be a vector
% 	nfft  - FFT length to use; default is the power of 2 just larger
% 	        than twice the length of x.
% 	sigma - sigma for the Choi-Williams window  [default = 0.05]
% 		large values of sigma are equivalent to no windowing;
% 	flag  - By default, if signal 'x' is real valued, its analytic form
% 	        is used to compute the WD; this helps supress cross terms
% 	        around D.C.;  if flag is 0, the analytic form is not used.
% 	wx    - the Wigner distribution
% 	        rows correspond to time, columns to frequencies
% 	        time increases with row number, frequencies with col number
% 	waxis - the frequency axis associated with the WD
%        It is recommended that the analytic form of the signal be used.

function wig3
%MATLAB Tour Partial Function Help:  hos_con
%
% WIG3	Computes the (f,f) slice of the Third-order Wigner Distribution
% 	[wx,waxis] = wig3 (x, nfft,flag)
% 	x     - time series, must be a vector
% 	nfft  - FFT length to use; default is the power of 2 just larger
% 	        than thrice the length of x.
% 	flag  - By default, if signal 'x' is real valued, its analytic form
% 	        is used to compute the WD; this helps supress cross terms
% 	        around D.C.;  if flag is 0, the analytic form is not used.
% 	wx    - The Thrid-Order Wigner distribution (TWD)
% 	        The TWD is a function of time and two-frequencies;
% 	        here we compute the `diagonal slice', f1=f2.
% 	        rows correspond to time, columns to frequencies
% 	        time increases with row number, frequencies with col number
% 	waxis - the frequency axis associated with the WD
%        It is recommended that the analytic form of the signal be used.

function wig3c
%MATLAB Tour Partial Function Help:  hos_con
%
% WIG3C	 Computes the (f,f) slice of the Third-order Wigner Distribution,
%         with Choi-Williams smoothing
% 	[wx,waxis] = wig3c (x, nfft, sigma,flag)
% 	x     - time series, must be a vector
% 	nfft  - FFT length to use; default is the power of 2 just larger
% 	        than thrice the length of x.
% 	sigma - sigma for the Choi-Williams window; default = 0.05
% 	        large values of sigma are equivalent to no windowing;
% 	        values greater than or equal to 100 are treated as infinity
% 	flag  - By default, if signal 'x' is real valued, its analytic form
% 	        is used to compute the WD; this helps supress cross terms
% 	        around D.C.;  if flag is 0, the analytic form is not used.
% 	wx    - The Thrid-Order Wigner distribution (TWD)
% 	        The TWD is a function of time and two-frequencies;
% 	        here we compute the `diagonal slice', f1=f2.
% 	        rows correspond to time, columns to frequencies
% 	        time increases with row number, frequencies with col number
% 	waxis - the frequency axis associated with the WD
%        It is recommended that the analytic form of the signal be used.

function wig4
%MATLAB Tour Partial Function Help:  hos_con
%
% WIG4	 Computes the f1=f2=-f3 slice of the Fourth-Order Wigner Distribution.
% 	[wx,waxis] = wig4 (x, nfft,flag)
% 	x     - time series, must be a vector
% 	nfft  - FFT length to use; default is the power of 2 just larger
% 	        than four times the length of x.
% 	flag  - By default, if signal 'x' is real valued, its analytic form
% 	        is used to compute the WD; this helps supress cross terms
% 	        around D.C.;  if flag is 0, the analytic form is not used.
% 	wx    - the f1=f2=-f3 slice of the Fourth-Order Wigner Distribution
% 	        rows correspond to time, columns to frequencies
% 	        time increases with row number, frequencies with col number
% 	waxis - the frequency axis associated with the WD
%        It is recommended that the analytic form of the signal be used.

function wig4c
%MATLAB Tour Partial Function Help:  hos_con
%
% WIG4C	 Computes the Sliced Reduced Interference Wigner Trispectrum
% 	[wx,waxis] = wig4c (x, nfft, sigma,flag)
% 	x     - time series, must be a vector
% 	nfft  - FFT length to use; default is the power of 2 just larger
% 	        than four times the length of x.
% 	sigma - sigma for the Choi-Williams window  [default = 0.05]
% 		large values of sigma are equivalent to no windowing;
% 	flag  - By default, if signal 'x' is real valued, its analytic form
% 	        is used to compute the WD; this helps supress cross terms
% 	        around D.C.;  if flag is 0, the analytic form is not used.
% 	wx    - the Sliced Reduced Interference Wigner Trispectrum
% 	        rows correspond to time, columns to frequencies
% 	        time increases with row number, frequencies with col number
% 	waxis - the frequency axis associated with the WD
%        It is recommended that the analytic form of the signal be used.

function hprony
%MATLAB Tour Partial Function Help:  hos_con
%
% HPRONY	Prony's method for modeling transients
% 	[a,theta,alpha,fr] = hprony (x,p)
% 	x  - transient signal
% 	p  - order    [default = length(x)/10]
% 	HPRONY fits the model:
% 	     x(n) = sum_{1 to p} A(k) z(k)^n
% 	where A(k) = a(k) exp (j * theta(k))
% 	and   z(k) = exp( alpha(k) + j * 2 * pi * fr (k) )
% 	The estimated values of a(k), theta(k), alpha(k) and fr(k)
% 	   k=1,...,p, are returned in the vectors, a, theta, alpha and fr.

function pickpeak
%MATLAB Tour Partial Function Help:  hos_con
%
% PICKPEAK Picks peaks 
%  [loc,val] = pickpeak(spec,npicks,rdiff)
% 	spec   - data vector or matrix 
% 	npicks - number of peaks desired              [default = 2]
% 	rdiff  - minimum spacing between picked peaks [default = 5]
%        loc    - vector of locations (indices) of the picked peaks
% 	val    - vector corresponding values 
% 	A 0 in location (i,j) of array loc (or a NaN in array val)
% 	indicates that the j-th data vector has less than i peaks
% 	with a separation of rdiff or more. 

function tls
%MATLAB Tour Partial Function Help:  hos_con
%
% TLS	Total-Least Squares solution to a set of linear equations
% 	[x,flag] = tls (A, b)
% 	Obtains the TLS solution to  A x = b
% 	Must have: # rows (A) >= # cols (A) + # cols(b)
% 	flag is set to 1, if the problem does not have a unique solution.

function trench
%MATLAB Tour Partial Function Help:  hos_con
%
% TRENCH	 Trench recursion (non-symmetric Toeplitz matrix)
% 	[amat,cmat, pfe,gamf,gamb] = trench(c,r)
% 	c     - first column of Toeplitz matrix, r(k), k=0,...,M
% 	r     - first row    of Toeplitz matrix, r(-k), k=0,...,M
% 	          defaults to c'.
% 	amat  - estimated forward AR predictors, of orders 1 through M
% 	        the k-th column contains the AR(k) coefficients
% 	cmat  - estimated backward AR predictors, of orders 1 through M
% 	        the k-th column contains the AR(k) coefficients
% 	pfe   - final prediction error variance for orders 1 through M
% 	        the k-th element contains the value for order k
% 	gamf   - estimated forward reflection coefficients
% 	gamb   - estimated backward reflection coefficients
% 

function hosahelp
%MATLAB Tour Partial Function Help:  hos_con
%
% HOSAHELP Higher-Order Spectral Analysis Toolbox -- Version 2.0.3 (R11) 10-Jul-1998
% 	  Quick one line help
%            [avec, bvec] = armaqs   (y,p,q,norder,maxlag,sampSeg,overlap,flag)
%            [avec, bvec] = armarts  (y,p,q,norder,maxlag,sampSeg,overlap,flag)
%                    zmat = armasyn  (default)
%                       p = arorder  (y,norder, pmax,qmax, flag)
%                    avec = arrcest  (y,p,q,norder,maxlag,sampSeg,overlap,flag)
% [he,ceps,A,B,minh,maxh] = biceps   (y,p,q,nsamp,overlap,flag,lh)
%             [hest,ceps] = bicepsf  (y,nlag,nsamp, overlap,flag, nfft, wind)
%             [bic,waxis] = bicoher  (y,  nfft, wind, nsamp, overlap)
% 	     [bic,waxis] = bicoherx (w,x,y,  nfft, wind, nsamp, overlap)
%           [Bspec,waxis] = bispecd  (y,  nfft, wind, nsamp, overlap)
%           [Bspec,waxis] = bispecdx (x, y, z,nfft,wind,nsamp,overlap,plotflag)
%           [Bspec,waxis] = bispeci  (y,nlag,nsamp, overlap,flag, nfft, wind)
%           [Bspec,waxis] = bispect  (ma, ar, nfft)
%                   y_cum = cum2est  (y, maxlag, nsamp, overlap, flag)
%                   y_cum = cum3est  (y, maxlag, nsamp, overlap, flag, k1)
%                   y_cum = cum4est  (y, maxlag, nsamp, overlap, flag, k1, k2)
%                   y_cum = cum2x    (x,y, maxlag, nsamp, overlap, flag)
%                   y_cum = cum3x    (x,y,z, maxlag, nsamp, overlap, flag, k1)
%                   y_cum = cum4x    (w,x,y,z,maxlag,nsamp,overlap,flag,k1,k2)
%                   y_cum = cumest   (y,norder,maxlag,nsamp,overlap,flag,k1,k2)
%                    cmat = cumtrue  (ma, ar, norder, nlags, k)
%    [spec,theta,bearing] = doa      (ymat, dspace, dtheta,nsource,order,delta)
%                    smat = doagen   (default)
%                [sg, sl] = glstat   (x,cparm,nfft)
%           [Pxx,ar1,ar2] = harmest  (y,maxlag,p_order,flag,nfft,norder)
%                    zmat = harmgen  (default)
% 	                   hosademo (figure_number)
% 			   hosahelp
%      [a,theta,alpha,fr] = hprony   (x,p)
%                       z = ivcal    (y, morder, lam)
%                    bvec = maest    (y,q, norder,samp_seg,overlap,flag)
%                    qopt = maorder  (x,qmin,qmax,pfa, flag)
%                    hest = matul    (bisp)
%                       y = nlgen    (x, h, q)
%                   [h,q] = nlpow    (x,y,nfft)
%                 [ht,qt] = nltick   (x,y,nfft, wind,segsamp,overlap)
% 	       [loc,val] = pickpeak (spec, npicks, rdiff)
%                    zdat = qpcgen   (default)
%          [ar_vec,Bspec] = qpctor   (y,maxlag,arOrder,nfft,nsamp,overlap,flag)
% [arvec, fref, bref,fpe] = rivdl    (y,morder,arorder,lam,delta,thres, nsmuth)
%        [arvec, fpe, wt] = rivtr    (y,morder,arorder, lambda, delta, nsmuth)
%                       u = rpiid    (nsamp, in_type,p_spike)
%            [delay,avec] = tde      (x,y,max_delay,  nsamp,svdflag)
%            [delay,ctau] = tdeb     (x,y,max_delay,  nfft,wind,nsamp,overlap)
%                [s1, s2] = tdegen   (default)
%             [delay,rxy] = tder     (x,y,max_delay,  segsamp,overlap,nfft)
%                [x,flag] = tls      (A,b)
%    [amat,cmat,pf,gf,gb] = trench   (c,r)
%           [Tspec,waxis] = trispect (ma, ar, nfft, f3)
%             [wx, waxis] = wig2     (x0,nfft,		flag)
%             [wx, waxis] = wig2c    (x0,nfft,sigma,	flag)
%             [wx, waxis] = wig3     (x0,nfft,		flag)
%             [wx, waxis] = wig3c    (x0,nfft,sigma,	flag)
%             [wx, waxis] = wig4     (x0,nfft,		flag)
%             [wx, waxis] = wig4c    (x0,nfft,sigma,	flag)
% 

function hosademo
%MATLAB Tour Partial Function Help:  hos_con
%
%  Higher-Order Spectral Analysis Toolbox - Demo suite
% 
%  hosademo : main demo file
% 	     all other .m files in this directory are invoked by hosademo
% 
%  Data files: 
% 
%  ar1.mat      - AR(2) synthetic
%  arma1.mat    - ARMA(2,1) synthetic
%  doa1.mat     - synthetic for DOA problem
%  gldat.mat    - data for Gaussianity/linearity tests
%  harm.mat     - synthetic for harmonics in noise problem
%  laff.dat     - a segment of laughter data
%  laff_b.mat   - pre-computed bispectrum of data in laff.dat 
%  lynx.dat     - the lynx data series
%  ma1.mat      - MA(3) synthetic
%  nl1.mat      - synthetic for testing non-linear routines
%  nl2.mat      - synthetic for testing non-linear routines
%  qpc.mat      - signal  for the quadratic phase coupling problem
%  riv.mat      - signals for the adaptive LP problem
%  tde1.mat     - signals for the time-delay estimation problem
%  tprony.mat   - signal  for testing Prony's method
%  wigdat.mat   - signals for testing the Wigner routines
%
%
%hosademo is both a directory and a function.
%
% HOSADEMO Demonstrates some of the capabilities of the HOSA Toolbox
% 	hosademo
% 
%         HOSADEMO  presents a menu of demos.
% 	 The HOSA Toolbox offers several routines for
% 	 Signal Processing with Higher-Order Spectra
% 	 The HOSA toolbox is a product of United Signals & Systems, Inc,
% 	 and was developed by Ananthram Swami.

